@@ -15,7 +15,7 @@ from hagworm.extend.logging import LogFileRotator
 
 from setting import ConfigDynamic
 from service.base import DataSource
-from controller import home
+from controller import router
 
 
 app = create_fastapi(
@@ -24,6 +24,7 @@ app = create_fastapi(
     log_file_rotation=LogFileRotator.make(ConfigDynamic.LogFileSplitSize, ConfigDynamic.LogFileSplitTime),
     log_file_retention=ConfigDynamic.LogFileBackups,
     debug=ConfigDynamic.Debug,
+    routes=router.routes,
     on_startup=[DataSource.initialize],
     on_shutdown=[DataSource.release],
 )
@@ -36,8 +37,6 @@ app.add_middleware(
     allow_credentials=ConfigDynamic.AllowCredentials,
 )
 
-app.include_router(home.router)
-
 
 if __name__ == r'__main__':
 
