@@ -4,6 +4,8 @@ import types
 import weakref
 import inspect
 import asyncio
+import functools
+import traceback
 
 import async_timeout
 
@@ -37,6 +39,14 @@ class Utils(base.Utils):
 
     sleep = staticmethod(asyncio.sleep)
 
+    @staticmethod
+    def is_coroutine_function(func):
+
+        if isinstance(func, functools.partial):
+            return asyncio.iscoroutinefunction(func.func)
+        else:
+            return asyncio.iscoroutinefunction(func)
+
     @staticmethod
     async def awaitable_wrapper(obj):
         """自适应awaitable对象
@@ -233,6 +243,9 @@ def async_adapter(func):
 
     """
 
+    if not Utils.is_coroutine_function(func):
+        return func
+
     @base.Utils.func_wraps(func)
     def _wrapper(*args, **kwargs):
 
@@ -565,7 +578,7 @@ class AsyncContextManager:
 
         return self
 
-    async def __aexit__(self, exc_type, exc_value, traceback):
+    async def __aexit__(self, exc_type, exc_value, _traceback):
 
         await self._context_release()
 
@@ -575,7 +588,7 @@ class AsyncContextManager:
 
         elif exc_value:
 
-            Utils.log.exception(exc_value)
+            Utils.log.exception(traceback.format_exc())
 
             return True
 
@@ -664,7 +677,8 @@ class FuncCache:
                     func(*args, **kwargs)
                 )
 
-                self._cache.set(func_sign, result)
+                if result is not None:
+                    self._cache.set(func_sign, result)
 
             return result
 
