@@ -30,7 +30,9 @@ class RedisPool:
         self._settings = settings
 
         self._settings[r'address'] = address
-        self._settings[r'password'] = password
+
+        if password:
+            self._settings[r'password'] = password
 
         self._settings[r'minsize'] = minsize
         self._settings[r'maxsize'] = maxsize
@@ -227,25 +229,39 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return await self._safe_execute(super().execute, command, *args, **kwargs)
 
-    def _val_encode(self, val):
+    @staticmethod
+    def _list_basestring(_list):
+
+        return [Utils.basestring(i) for i in _list]
+
+    @staticmethod
+    def _val_encode(val):
 
         return Utils.pickle_dumps(val)
 
-    def _val_decode(self, val):
+    @staticmethod
+    def _val_decode(val):
 
         return Utils.pickle_loads(val)
 
+    def _list_decode(self, _list):
+
+        return map(
+            lambda i: self._val_decode(i) if i else i,
+            _list
+        )
+
     def key(self, key, *args, **kwargs):
 
         if self._key_prefix:
-            key = f'{self._key_prefix}_{key}'
+            key = f'{self._key_prefix}:{key}'
 
         if not args and not kwargs:
             return key
 
         sign = Utils.params_sign(*args, **kwargs)
 
-        return f'{key}_{sign}'
+        return f'{key}:{sign}'
 
     def allocate_lock(self, key, expire=60):
 
@@ -363,7 +379,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().scan(cursor, match, count)
 
         if result is not None:
-            result = (result[0], [Utils.basestring(val) for val in result[1]])
+            result = (result[0], self._list_basestring(result[1]))
 
         return result
 
@@ -406,7 +422,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().mget(key, *keys)
 
         if result is not None:
-            result = [self._val_decode(val) for val in result]
+            result = list(self._list_decode(result))
 
         return result
 
@@ -496,7 +512,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().sdiff(key, *keys)
 
         if result is not None:
-            result = [Utils.basestring(val) for val in result]
+            result = self._list_basestring(result)
 
         return result
 
@@ -509,7 +525,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().sinter(key, *keys)
 
         if result is not None:
-            result = [Utils.basestring(val) for val in result]
+            result = self._list_basestring(result)
 
         return result
 
@@ -522,7 +538,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().smembers(key)
 
         if result is not None:
-            result = [Utils.basestring(val) for val in result]
+            result = self._list_basestring(result)
 
         return result
 
@@ -548,7 +564,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().srandmember(key, count)
 
         if result is not None:
-            result = [Utils.basestring(val) for val in result]
+            result = self._list_basestring(result)
 
         return result
 
@@ -561,7 +577,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().sunion(key, *keys)
 
         if result is not None:
-            result = [Utils.basestring(val) for val in result]
+            result = self._list_basestring(result)
 
         return result
 
@@ -574,7 +590,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().sscan(key, cursor, match, count)
 
         if result is not None:
-            result = (result[0], [Utils.basestring(val) for val in result[1]])
+            result = (result[0], self._list_basestring(result[1]))
 
         return result
 
@@ -628,7 +644,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().hmget(key, field, *fields)
 
         if result is not None:
-            result = [self._val_decode(val) for val in result]
+            result = list(self._list_decode(result))
 
         return result
 
@@ -690,7 +706,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().hvals(key)
 
         if result is not None:
-            result = [self._val_decode(val) for val in result]
+            result = list(self._list_decode(result))
 
         return result
 
@@ -821,7 +837,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
         result = await super().lrange(key, start, stop)
 
         if result is not None:
-            result = [self._val_decode(val) for val in result]
+            result = list(self._list_decode(result))
 
         return result
 
@@ -955,7 +971,7 @@ end
 
         if self._locked:
 
-            await self.renew()
+            self._locked = await self.renew()
 
         else:
 
