@@ -518,7 +518,7 @@ class _ClientBase:
         if not isinstance(query, Select):
             raise TypeError(r'Not sqlalchemy.sql.selectable.Select object')
 
-        proxy = await self.execute(query, *multiparams, **params)
+        proxy = await self.execute(query.limit(1), *multiparams, **params)
 
         if proxy is not None:
 
@@ -532,6 +532,12 @@ class _ClientBase:
 
         return result
 
+    async def count(self, query, *multiparams, **params):
+
+        result = await self.find(query, *multiparams, **params)
+
+        return result[r'tbl_row_count']
+
     async def insert(self, query, *multiparams, **params):
 
         result = 0
