@@ -1,11 +1,18 @@
 # -*- coding: utf-8 -*-
 
-from aioredis.pubsub import Receiver
-
 from hagworm.extend.event import EventDispatcher
 from hagworm.extend.asyncio.base import Utils, AsyncCirculatorForSecond, FuncWrapper, FutureWithTimeout
 
 
+class EventDispatcher(EventDispatcher):
+    """支持异步函数的事件总线
+    """
+
+    def _gen_observer(self):
+
+        return FuncWrapper()
+
+
 class DistributedEvent(EventDispatcher):
     """Redis实现的消息广播总线
     """
@@ -32,14 +39,12 @@ class DistributedEvent(EventDispatcher):
                 Utils.log.info(f'event bus channel({channel}) receiver created')
 
                 async for message in receiver.iter():
-                    await self._event_assigner(channel, message)
+                    await self._event_assigner(message)
 
-    async def _event_assigner(self, channel, message):
+    async def _event_assigner(self, message):
 
         message = Utils.pickle_loads(message)
 
-        Utils.log.debug(f'event handling => channel({channel}) message({message})')
-
         _type = message.get(r'type', r'')
         args = message.get(r'args', [])
         kwargs = message.get(r'kwargs', {})
@@ -61,8 +66,6 @@ class DistributedEvent(EventDispatcher):
             r'kwargs': kwargs,
         }
 
-        Utils.log.debug(f'event dispatch => channel({channel}) message({message})')
-
         async with self._redis_pool.get_client() as cache:
             await cache.publish(channel, Utils.pickle_dumps(message))
 
