@@ -29,7 +29,7 @@ class FileLoader:
 
         try:
 
-            if self._cache.exists(file):
+            if self._cache.has(file):
 
                 result = self._cache.get(file)
 
@@ -51,7 +51,7 @@ class FileLoader:
 
         try:
 
-            if self._cache.exists(url):
+            if self._cache.has(url):
 
                 result = self._cache.get(url)
 
