@@ -4,8 +4,9 @@ import os
 import ssl
 import aiohttp
 
-from enum import Enum
+from contextlib import contextmanager
 
+from hagworm.extend.struct import Enum
 from hagworm.extend.base import ContextManager
 from hagworm.extend.asyncio.base import AsyncCirculatorForSecond
 from hagworm.extend.asyncio.buffer import FileBuffer
@@ -30,6 +31,30 @@ CACERT_FILE = os.path.join(
 )
 
 
+@contextmanager
+def _catch_error():
+    """异常捕获
+
+    通过with语句捕获异常，代码更清晰，还可以使用Ignore异常安全的跳出with代码块
+
+    """
+
+    try:
+
+        yield
+
+    except aiohttp.ClientResponseError as err:
+
+        if err.status < 500:
+            Utils.log.warning(err)
+        else:
+            Utils.log.error(err)
+
+    except Exception as err:
+
+        Utils.log.error(err)
+
+
 class _AsyncCirculator(AsyncCirculatorForSecond):
 
     async def _sleep(self):
@@ -42,7 +67,7 @@ def _json_decoder(val, **kwargs):
     try:
         return Utils.json_decode(val, **kwargs)
     except Exception as err:
-        Utils.log.error(f'http client json decode error: {err} => {val}')
+        Utils.log.warning(f'http client json decode error: {err} => {val}')
 
 
 class Result(dict):
@@ -97,7 +122,9 @@ class _HTTPClient:
 
         return ssl.create_default_context(cafile=CACERT_FILE)
 
-    def create_timeout(self, *, total=None, connect=None, sock_read=None, sock_connect=None):
+    def create_timeout(
+            self, *, total=None, connect=None, sock_read=None, sock_connect=None
+    ) -> aiohttp.client.ClientTimeout:
         """生成超时配置对象
 
         Args:
@@ -113,7 +140,13 @@ class _HTTPClient:
             sock_read=sock_read, sock_connect=sock_connect
         )
 
-    async def send_request(self, method, url, data=None, params=None, cookies=None, headers=None, **settings) -> Result:
+    def create_form_data(self) -> aiohttp.FormData:
+
+        return aiohttp.FormData()
+
+    async def send_request(
+            self, method, url, data=None, params=None, cookies=None, headers=None, **settings
+    ) -> Result:
 
         response = None
 
@@ -164,7 +197,7 @@ class _HTTPClient:
                 elif times >= self._retry_count:
                     raise err
                 else:
-                    Utils.log.error(err)
+                    Utils.log.warning(err)
                     continue
 
             except aiohttp.ClientError as err:
@@ -172,7 +205,7 @@ class _HTTPClient:
                 if times >= self._retry_count:
                     raise err
                 else:
-                    Utils.log.error(err)
+                    Utils.log.warning(err)
                     continue
 
             except Exception as err:
@@ -227,112 +260,84 @@ class HTTPClient(_HTTPClient):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_GET, url, None, params, cookies=cookies, headers=headers)
 
             result = resp.body
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def options(self, url, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_OPTIONS, url, None, params, cookies=cookies, headers=headers)
 
             result = resp.headers
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def head(self, url, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_HEAD, url, None, params, cookies=cookies, headers=headers)
 
             result = resp.headers
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def post(self, url, data=None, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_POST, url, data, params, cookies=cookies, headers=headers)
 
             result = resp.body
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def put(self, url, data=None, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_PUT, url, data, params, cookies=cookies, headers=headers)
 
             result = resp.body
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def patch(self, url, data=None, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_PATCH, url, data, params, cookies=cookies, headers=headers)
 
             result = resp.body
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
     async def delete(self, url, params=None, *, cookies=None, headers=None):
 
         result = None
 
-        try:
+        with _catch_error():
 
             resp = await self.send_request(aiohttp.hdrs.METH_DELETE, url, None, params, cookies=cookies, headers=headers)
 
             result = resp.body
 
-        except Exception as err:
-
-            Utils.log.error(err)
-
         return result
 
 
