@@ -31,7 +31,7 @@ class TaskAbstract(TaskInterface):
             job_defaults={
                 r'coalesce': False,
                 r'max_instances': 1,
-                r'misfire_grace_time': 30
+                r'misfire_grace_time': 10
             },
             timezone=TIMEZONE
         ) if scheduler is None else scheduler
@@ -41,6 +41,21 @@ class TaskAbstract(TaskInterface):
 
         return self._scheduler
 
+    @staticmethod
+    def _func_wrapper(func, *args, **kwargs):
+
+        if Utils.is_coroutine_function(func):
+
+            if args or kwargs:
+                return Utils.func_partial(func, *args, **kwargs)
+            else:
+                return func
+
+        async def _wrapper():
+            return func(*args, **kwargs)
+
+        return _wrapper
+
     def is_running(self):
 
         return self._scheduler.running
@@ -81,12 +96,10 @@ class IntervalTask(TaskAbstract):
 
     def add_job(self, interval, func, *args, **kwargs):
 
-        if args or kwargs:
-            _func = Utils.func_partial(func, *args, **kwargs)
-        else:
-            _func = func
-
-        return self._scheduler.add_job(_func, r'interval', seconds=interval)
+        return self._scheduler.add_job(
+            self._func_wrapper(func, *args, **kwargs),
+            r'interval', seconds=interval
+        )
 
 
 class CronTask(TaskAbstract):
@@ -104,12 +117,10 @@ class CronTask(TaskAbstract):
 
     def add_job(self, crontab, func, *args, **kwargs):
 
-        if args or kwargs:
-            _func = Utils.func_partial(func, *args, **kwargs)
-        else:
-            _func = func
-
-        return self._scheduler.add_job(_func, CronTrigger.from_crontab(crontab, TIMEZONE))
+        return self._scheduler.add_job(
+            self._func_wrapper(func, *args, **kwargs),
+            CronTrigger.from_crontab(crontab, TIMEZONE)
+        )
 
 
 class RateLimiter:
