@@ -50,7 +50,7 @@ class _SocketBase(ContextManager):
 
     def close(self):
 
-        if not self._socket.closed:
+        if self._socket and not self._socket.closed:
             self._socket.close()
             self._socket = None
 
@@ -73,7 +73,6 @@ class _SocketBase(ContextManager):
 
         return result
 
-
     async def recv(self, noblock=False):
 
         result = None
@@ -134,10 +133,10 @@ class PublishWithBuffer(_SocketBase, QueueBuffer):
                 super().close()
                 break
 
+
 ##################################################
 # 请求模式
 
-
 class Request(_SocketBase):
 
     def __init__(self, address, *, name=None):
@@ -151,10 +150,10 @@ class Reply(_SocketBase):
 
         super().__init__(name, zmq.REP, address, True)
 
+
 ##################################################
 # 推拉模式
 
-
 class Push(_SocketBase):
 
     def __init__(self, address, bind_mode=False, *, name=None):
