@@ -28,14 +28,17 @@ import struct
 import unicodedata
 import calendar
 import jwt
+import yaml
 import loguru
 import warnings
+import traceback
 import xmltodict
 import xml.dom.minidom
 
 from datetime import datetime, timedelta
 from contextlib import contextmanager, closing
-from collections import Iterable, OrderedDict
+from collections import OrderedDict
+from collections.abc import Iterable
 from cachetools import cached, TTLCache
 from zipfile import ZipFile, ZIP_DEFLATED
 
@@ -131,25 +134,46 @@ class Utils:
         return ujson.loads(cls.basestring(val), **kwargs)
 
     @classmethod
-    def today(cls, origin=False):
+    def today(cls):
 
         result = datetime.now()
 
-        return result.replace(hour=0, minute=0, second=0, microsecond=0) if origin else result
+        return result.replace(hour=0, minute=0, second=0, microsecond=0)
 
     @classmethod
-    def yesterday(cls, origin=False):
+    def yesterday(cls):
 
         result = datetime.now() - timedelta(days=1)
 
-        return result.replace(hour=0, minute=0, second=0, microsecond=0) if origin else result
+        return result.replace(hour=0, minute=0, second=0, microsecond=0)
 
     @classmethod
-    def utcnow(cls, origin=False):
+    def localnow(cls):
+
+        result = datetime.now()
+
+        return result.replace(second=0, microsecond=0)
+
+    @classmethod
+    def localnow_on_hour(cls):
+
+        result = datetime.now()
+
+        return result.replace(minute=0, second=0, microsecond=0)
+
+    @classmethod
+    def utcnow(cls):
 
         result = datetime.utcnow()
 
-        return result.replace(hour=0, minute=0, second=0, microsecond=0) if origin else result
+        return result.replace(second=0, microsecond=0)
+
+    @classmethod
+    def utcnow_on_hour(cls):
+
+        result = datetime.utcnow()
+
+        return result.replace(minute=0, second=0, microsecond=0)
 
     @classmethod
     def timestamp(cls, msec=False):
@@ -209,7 +233,7 @@ class Utils:
     @classmethod
     def split_int(cls, val, sep=r',', minsplit=0, maxsplit=-1):
 
-        result = [int(item.strip()) for item in val.split(sep, maxsplit) if item.strip().isdigit()]
+        result = [int(item.strip()) for item in val.split(sep, maxsplit) if item.strip().lstrip(r'-').isdigit()]
 
         fill = minsplit - len(result)
 
@@ -340,12 +364,34 @@ class Utils:
 
         seed_num = None
 
-        with open(r'/dev/urandom', r'rb') as f:
-            seed_num = struct.unpack(f'!I', f.read(4))[0]
-            random.seed(seed_num)
+        try:
+
+            with open(r'/dev/urandom', r'rb') as f:
+                seed_num = struct.unpack(f'!I', f.read(4))[0]
+                random.seed(seed_num)
+
+        except Exception as _:
+
+            cls.log.warning(r'SYSTEM DOES NOT SUPPORT URANDOM')
 
         return seed_num
 
+    @classmethod
+    def read_urandom(cls, size):
+
+        result = None
+
+        try:
+
+            with open(r'/dev/urandom', r'rb') as f:
+                result = f.read(size)
+
+        except Exception as _:
+
+            cls.log.warning(r'SYSTEM DOES NOT SUPPORT URANDOM')
+
+        return result
+
     @classmethod
     def get_host_ip(cls):
 
@@ -560,18 +606,28 @@ class Utils:
             return cls.basestring(result)
 
     @classmethod
-    def jwt_encode(cls, val, key):
+    def jwt_encode(cls, val, key, algorithms=r'HS256'):
 
-        result = jwt.encode(val, key)
+        result = jwt.encode(val, key, algorithms)
 
         return cls.basestring(result)
 
     @classmethod
-    def jwt_decode(cls, val, key):
+    def jwt_decode(cls, val, key, algorithms=[r'HS256']):
 
         val = cls.utf8(val)
 
-        return jwt.decode(val, key)
+        return jwt.decode(val, key, algorithms)
+
+    @classmethod
+    def yaml_encode(cls, data, stream=None):
+
+        return yaml.safe_dump(data, stream)
+
+    @classmethod
+    def yaml_decode(cls, stream):
+
+        return yaml.safe_load(stream)
 
     @classmethod
     def pickle_dumps(cls, val):
@@ -596,6 +652,11 @@ class Utils:
 
         return uuid.uuid1(node, clock_seq).hex
 
+    @classmethod
+    def uuid1_urn(cls, node=None, clock_seq=None):
+
+        return str(uuid.uuid1(node, clock_seq))
+
     @classmethod
     def crc32(cls, val):
 
@@ -750,7 +811,7 @@ class Utils:
     def get_today_region(cls, today=None):
 
         if today is None:
-            today = cls.today(True)
+            today = cls.today()
 
         start_date = today
         end_date = today + timedelta(days=1)
@@ -764,7 +825,7 @@ class Utils:
     def get_month_region(cls, today=None):
 
         if today is None:
-            today = cls.today(True)
+            today = cls.today()
 
         start_date = today.replace(day=1)
 
@@ -782,7 +843,7 @@ class Utils:
     def get_week_region(cls, today=None):
 
         if today is None:
-            today = cls.today(True)
+            today = cls.today()
 
         week_pos = today.weekday()
 
@@ -874,9 +935,31 @@ class Ignore(BaseError):
         return self._layers > 0
 
 
+@contextmanager
+def catch_warning():
+    """异常捕获，打印warning级日志
+
+    通过with语句捕获异常，代码更清晰，还可以使用Ignore异常安全的跳出with代码块
+
+    """
+
+    try:
+
+        yield
+
+    except Ignore as err:
+
+        if err.throw():
+            raise err
+
+    except Exception as err:
+
+        Utils.log.warning(err)
+
+
 @contextmanager
 def catch_error():
-    """异常捕获
+    """异常捕获，打印error级日志
 
     通过with语句捕获异常，代码更清晰，还可以使用Ignore异常安全的跳出with代码块
 
@@ -913,7 +996,7 @@ class ContextManager:
 
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback):
+    def __exit__(self, exc_type, exc_value, _traceback):
 
         self._context_release()
 
@@ -923,7 +1006,7 @@ class ContextManager:
 
         elif exc_value:
 
-            Utils.log.exception(exc_value)
+            Utils.log.exception(traceback.format_exc())
 
             return True
 
