@@ -1,6 +1,14 @@
 # -*- coding: utf-8 -*-
 
 
+class FunctorInterface:
+    """仿函数接口定义
+    """
+
+    def __call__(self):
+        raise NotImplementedError()
+
+
 class RunnableInterface:
     """Runnable接口定义
     """
