@@ -4,6 +4,7 @@ import re
 import struct
 import threading
 
+from enum import Enum as _Enum
 from io import BytesIO
 from collections import OrderedDict
 from configparser import RawConfigParser
@@ -12,19 +13,61 @@ from .base import Utils
 from .error import ConstError
 
 
+class Enum(_Enum):
+
+    @classmethod
+    def items(cls):
+
+        return [(item.name, item.value,) for item in cls]
+
+    @classmethod
+    def keys(cls):
+
+        return [item.name for item in cls]
+
+    @classmethod
+    def values(cls):
+
+        return [item.value for item in cls]
+
+    @classmethod
+    def to_dict(cls):
+
+        return {item.name: item.value for item in cls}
+
+    @classmethod
+    def to_keys_dict(cls):
+
+        return {item.name: item for item in cls}
+
+    @classmethod
+    def to_values_dict(cls):
+
+        return {item.value: item for item in cls}
+
+    @classmethod
+    def has_key(cls, key):
+
+        return key in cls.keys()
+
+    @classmethod
+    def has_value(cls, value):
+
+        return value in cls.values()
+
+
 class Result(dict):
     """返回结果类
     """
 
-    def __init__(self, code=0, data=None, extra=None):
+    def __init__(self, code=0, data=None, **kwargs):
 
         super().__init__(code=code)
 
         if data is not None:
             self.__setitem__(r'data', data)
 
-        if extra is not None:
-            self.__setitem__(r'extra', extra)
+        self.update(kwargs)
 
     def __bool__(self):
 
@@ -40,11 +83,6 @@ class Result(dict):
 
         return self.get(r'data', None)
 
-    @property
-    def extra(self):
-
-        return self.get(r'extra', None)
-
 
 class NullData:
     """NULL类，用于模拟None对象的行为
