@@ -1,83 +1,55 @@
 # -*- coding: utf-8 -*-
 
-import os
-
 from terminal_table import Table
 
-from hagworm.extend.interface import RunnableInterface
-from hagworm.extend.asyncio.base import Launcher as _Launcher
-from hagworm.extend.asyncio.base import Utils, MultiTasks, AsyncCirculatorForSecond
-from hagworm.extend.asyncio.zmq import Subscriber, PublisherWithBuffer
+from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR
+from hagworm.extend.interface import FunctorInterface, RunnableInterface
+from hagworm.extend.asyncio import command
+from hagworm.extend.asyncio.base import Utils, MultiTasks, AsyncCirculator
+from hagworm.extend.asyncio.zmq import Subscribe, PublishWithBuffer
 
 
 SIGNAL_PROTOCOL = r'tcp'
-SIGNAL_PORT = 0x310
+SIGNAL_PORT = 0x601
 HIGH_WATER_MARK = 0xffffff
 
 
-class Guardian(RunnableInterface):
+class Daemon(command.Daemon):
 
-    async def _do_polling(self, pids, hwm):
+    async def _run(self):
 
         with Reporter() as reporter:
 
-            reporter.set_hwm(hwm)
+            async for _ in AsyncCirculator():
 
-            async for _ in AsyncCirculatorForSecond():
+                stopped = self._check_pids()
 
-                for pid in pids.copy():
-                    if os.waitpid(pid, os.WNOHANG)[0] == pid:
-                        pids.remove(pid)
+                await reporter.handle_message()
 
-                if len(pids) == 0:
+                if stopped:
                     break
 
             Utils.log.info(f'\n{reporter.get_report_table()}')
 
-    def run(self, pids):
 
-        global HIGH_WATER_MARK
-
-        Utils.run_until_complete(self._do_polling(pids, HIGH_WATER_MARK))
+_DEFAULT_DAEMON = Daemon()
 
 
-class Launcher(_Launcher):
+class Launcher(command.Launcher):
 
     def __init__(self,
-                 log_file_path=None, log_level=r'INFO', log_file_num_backups=7,
-                 process_number=1, process_guardian=None,
-                 debug=False
+                 log_file_path=None, log_level=r'INFO',
+                 log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff,
+                 subprocess=1, daemon=_DEFAULT_DAEMON, debug=False
                  ):
 
-        if process_guardian is None:
-            process_guardian = Guardian().run
-
         super().__init__(
-            log_file_path, log_level, log_file_num_backups,
-            process_number, process_guardian,
-            debug
+            log_file_path, log_level, log_file_rotation, log_file_retention,
+            subprocess, daemon, debug
         )
 
-    def run(self, func, *args, **kwargs):
 
-        if self._process_number > 1:
-
-            super().run(func, *args, **kwargs)
-
-        else:
-
-            async def _func():
-
-                nonlocal func, args, kwargs
-
-                with Reporter() as reporter:
-                    await func(*args, **kwargs)
-                    Utils.log.info(f'\n{reporter.get_report_table()}')
-
-            super().run(_func)
-
-
-class Reporter(Subscriber):
+class Reporter(Subscribe):
 
     class _Report:
 
@@ -87,19 +59,24 @@ class Reporter(Subscriber):
 
     def __init__(self):
 
-        global SIGNAL_PROTOCOL, SIGNAL_PORT, HIGH_WATER_MARK
+        global SIGNAL_PROTOCOL, SIGNAL_PORT
 
         super().__init__(f'{SIGNAL_PROTOCOL}://*:{SIGNAL_PORT}', True)
 
-        self.set_hwm(HIGH_WATER_MARK)
-
         self._reports = {}
 
-    async def _message_handler(self, data):
+    async def handle_message(self):
 
-        for name, result, resp_time in data:
-            if name and result in (r'success', r'failure'):
-                getattr(self._get_report(name), result).append(resp_time)
+        while True:
+
+            message = await self.recv(True)
+
+            if message is None:
+                break
+
+            for name, result, resp_time in message:
+                if name and result in (r'success', r'failure'):
+                    getattr(self._get_report(name), result).append(resp_time)
 
     def _get_report(self, name: str) -> _Report:
 
@@ -108,6 +85,12 @@ class Reporter(Subscriber):
 
         return self._reports[name]
 
+    def open(self):
+
+        global HIGH_WATER_MARK
+
+        super().open(HIGH_WATER_MARK)
+
     def get_report_table(self) -> str:
 
         reports = []
@@ -142,7 +125,7 @@ class Reporter(Subscriber):
 
 class TaskInterface(Utils, RunnableInterface):
 
-    def __init__(self, publisher: PublisherWithBuffer):
+    def __init__(self, publisher: PublishWithBuffer):
 
         self._publisher = publisher
 
@@ -162,16 +145,16 @@ class TaskInterface(Utils, RunnableInterface):
         raise NotImplementedError()
 
 
-class Runner(Utils, RunnableInterface):
+class Runner(Utils, FunctorInterface):
 
     def __init__(self, task_cls: TaskInterface):
 
         global SIGNAL_PROTOCOL, SIGNAL_PORT
 
         self._task_cls = task_cls
-        self._publisher = PublisherWithBuffer(f'{SIGNAL_PROTOCOL}://localhost:{SIGNAL_PORT}', False)
+        self._publisher = PublishWithBuffer(f'{SIGNAL_PROTOCOL}://localhost:{SIGNAL_PORT}', False)
 
-    async def run(self, times, task_num):
+    async def __call__(self, process_id, times, task_num):
 
         self._publisher.open()
 
