@@ -149,28 +149,30 @@ class Launcher(_LauncherBase):
 
     """
 
-    def __init__(self, router, port=80, **kwargs):
+    def __init__(self, router, port=80, *, server_settings=None, **kwargs):
 
         super().__init__(**kwargs)
 
-        self._settings = {
+        self._server_settings = {} if server_settings is None else server_settings
+
+        self._app_settings = {
             r'handlers': router,
             r'debug': self._debug,
             r'gzip': kwargs.get(r'gzip', False),
         }
 
         if r'template_path' in kwargs:
-            self._settings[r'template_loader'] = Jinja2Loader(
+            self._app_settings[r'template_loader'] = Jinja2Loader(
                 jinja2.Environment(
                     loader=jinja2.FileSystemLoader(kwargs[r'template_path'])
                 )
             )
 
         if r'static_path' in kwargs:
-            self._settings[r'static_path'] = kwargs[r'static_path']
+            self._app_settings[r'static_path'] = kwargs[r'static_path']
 
         if r'cookie_secret' in kwargs:
-            self._settings[r'cookie_secret'] = kwargs[r'cookie_secret']
+            self._app_settings[r'cookie_secret'] = kwargs[r'cookie_secret']
 
         self._sockets = bind_sockets(port)
 
@@ -182,9 +184,9 @@ class Launcher(_LauncherBase):
         AsyncIOMainLoop().install()
 
         self._event_loop = asyncio.get_event_loop()
-        self._event_loop.set_debug(self._settings[r'debug'])
+        self._event_loop.set_debug(self._app_settings[r'debug'])
 
         self._event_loop.add_signal_handler(signal.SIGINT, self.stop)
         self._event_loop.add_signal_handler(signal.SIGTERM, self.stop)
 
-        self._server = HTTPServer(_Application(**self._settings))
+        self._server = HTTPServer(_Application(**self._app_settings), **self._server_settings)
