@@ -527,7 +527,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         try:
             result = self.json_encode(chunk)
         except Exception as _:
-            self.log.error(f'json encode error: {chunk}')
+            self.log.warning(f'json encode error: {chunk}')
 
         return self.finish(result)
 
@@ -681,7 +681,7 @@ class HTTPProxy(HTTPClientPool):
 
         except aiohttp.ClientResponseError as err:
 
-            Utils.log.error(err)
+            Utils.log.warning(err)
 
             handler.send_error(err.status, reason=err.message)
 
