@@ -3,49 +3,52 @@
 from mq_http_sdk.mq_client import MQClient as _MQClient
 from mq_http_sdk.mq_consumer import MQConsumer as _MQConsumer
 from mq_http_sdk.mq_producer import MQProducer as _MQProducer, MQTransProducer as _MQTransProducer
-from mq_http_sdk.mq_exception import MQServerException
+from mq_http_sdk.mq_exception import MQServerException, MQClientNetworkException
 
 from hagworm.extend.interface import TaskInterface
-from hagworm.extend.asyncio.base import Utils
+from hagworm.extend.asyncio.base import Utils, AsyncCirculator
 from hagworm.extend.asyncio.task import IntervalTask
 from hagworm.extend.asyncio.future import ThreadPool
 
 
+CLIENT_NETWORK_ERROR_RETRY_COUNT = 5
+
+
 class MQConsumer(_MQConsumer):
 
     async def consume_message(self, batch_size=1, wait_seconds=-1):
 
-        return await self.mq_client.thread_pool.run(super().consume_message, batch_size, wait_seconds)
+        return await self.mq_client.thread_run(super().consume_message, batch_size, wait_seconds)
 
     async def ack_message(self, receipt_handle_list):
 
-        return await self.mq_client.thread_pool.run(super().ack_message, receipt_handle_list)
+        return await self.mq_client.thread_run(super().ack_message, receipt_handle_list)
 
 
 class MQProducer(_MQProducer):
 
     async def publish_message(self, message):
 
-        return await self.mq_client.thread_pool.run(super().publish_message, message)
+        return await self.mq_client.thread_run(super().publish_message, message)
 
 
 class MQTransProducer(_MQTransProducer):
 
     async def publish_message(self, message):
 
-        return await self.mq_client.thread_pool.run(super().publish_message, message)
+        return await self.mq_client.thread_run(super().publish_message, message)
 
     async def consume_half_message(self, batch_size=1, wait_seconds=-1):
 
-        return await self.mq_client.thread_pool.run(super().consume_half_message, batch_size, wait_seconds)
+        return await self.mq_client.thread_run(super().consume_half_message, batch_size, wait_seconds)
 
     async def commit(self, receipt_handle):
 
-        return await self.mq_client.thread_pool.run(super().commit, receipt_handle)
+        return await self.mq_client.thread_run(super().commit, receipt_handle)
 
     async def rollback(self, receipt_handle):
 
-        return await self.mq_client.thread_pool.run(super().rollback, receipt_handle)
+        return await self.mq_client.thread_run(super().rollback, receipt_handle)
 
 
 class _TaskMixin(TaskInterface):
@@ -65,7 +68,7 @@ class _TaskMixin(TaskInterface):
     def is_running(self):
         self._task.is_running()
 
-    def _do_task(self):
+    async def _do_task(self):
         raise NotImplementedError()
 
 
@@ -78,10 +81,31 @@ class MQClient(_MQClient):
         # 原版SDK中的MQClient线程不安全，利用线程池仅有一个线程这种特例，保证线程安全
         self._thread_pool = ThreadPool(1)
 
-    @property
-    def thread_pool(self):
+    async def thread_run(self, func, *args, **kwargs):
 
-        return self._thread_pool
+        global CLIENT_NETWORK_ERROR_RETRY_COUNT
+
+        result = None
+
+        # 增加网络异常重试机制
+        async for times in AsyncCirculator(max_times=CLIENT_NETWORK_ERROR_RETRY_COUNT):
+
+            try:
+
+                result = await self._thread_pool.run(func, *args, **kwargs)
+
+            except MQClientNetworkException as err:
+
+                if times < CLIENT_NETWORK_ERROR_RETRY_COUNT:
+                    Utils.log.warning(err)
+                else:
+                    raise err
+
+            else:
+
+                break
+
+        return result
 
     def get_consumer(self, instance_id, topic_name, consumer, message_tag=r''):
 
